@@ -1,11 +1,13 @@
 package WordList::Phrase::EN::Proverb::TWW;
 
 our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
+our %STATS = ("avg_word_len",37.4152542372881,"num_words",472,"num_words_contains_unicode",0,"longest_word_len",97,"shortest_word_len",13,"num_words_contains_whitespace",472,"num_words_contains_nonword_chars",472); # STATS
+
 1;
 # ABSTRACT: Proverb phrases from Tom Wills
 
@@ -22,7 +24,7 @@ WordList::Phrase::EN::Proverb::TWW - Proverb phrases from Tom Wills
 
 =head1 VERSION
 
-This document describes version 0.02 of WordList::Phrase::EN::Proverb::TWW (from Perl distribution WordList-Phrase-EN-Proverb-TWW), released on 2016-01-13.
+This document describes version 0.03 of WordList::Phrase::EN::Proverb::TWW (from Perl distribution WordList-Phrase-EN-Proverb-TWW), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
@@ -43,6 +45,22 @@ This document describes version 0.02 of WordList::Phrase::EN::Proverb::TWW (from
  # Get all the words
  my @all_words = $wl->all_words;
 
+=head1 STATISTICS
+
+ +----------------------------------+------------------+
+ | key                              | value            |
+ +----------------------------------+------------------+
+ | avg_word_len                     | 37.4152542372881 |
+ | longest_word_len                 | 97               |
+ | num_words                        | 472              |
+ | num_words_contains_nonword_chars | 472              |
+ | num_words_contains_unicode       | 0                |
+ | num_words_contains_whitespace    | 472              |
+ | shortest_word_len                | 13               |
+ +----------------------------------+------------------+
+
+The statistics is available in the C<%STATS> package variable.
+
 =head1 SEE ALSO
 
 Converted from L<Games::Word::Phraselist::Proverb::TWW> 0.01.
